===============
SPIB-WE plug-in
===============


.. image:: https://img.shields.io/pypi/v/spib_we.svg
        :target: https://pypi.python.org/pypi/spib_we

.. image:: https://img.shields.io/travis/wangdedi1997/spib_we.svg
        :target: https://travis-ci.com/wangdedi1997/spib_we

.. image:: https://readthedocs.org/projects/spib-we/badge/?version=latest
        :target: https://spib-we.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




This is a WESTPA 2.0 plug-in for SPIB augmented weighted ensemble.


* Free software: MIT license
* Documentation: https://spib-we.readthedocs.io.


Features
--------

* Employ SPIB to automatically construct low-dimensional CVs to augment weighted ensemble simulations;
* Implement a rectilinear grid binning scheme to automatically determine bin sizes for uniformly binning SPIB-learned CVs;
* Propose a hybrid approach that combines SPIB-learned CVs with expert-based CVs to achieve more reliable sampling.


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
